@@ -681,7 +681,7 @@ class ClusterCreate(ClusterCommand):
         deployment_properties = DeploymentProperties(
             mode=DeploymentMode.incremental,
             template=template,
-            paramaters=deployment_parameters
+            parameters=deployment_parameters
         )
 
         utils.cod_log(log, "Creating and deploying Head node", 85)
